diff --git a/core/modules/migrate/src/Plugin/migrate/process/SkipRowIfNotSet.php b/core/modules/migrate/src/Plugin/migrate/process/SkipRowIfNotSet.php
index ab7552e..85446eb 100644
--- a/core/modules/migrate/src/Plugin/migrate/process/SkipRowIfNotSet.php
+++ b/core/modules/migrate/src/Plugin/migrate/process/SkipRowIfNotSet.php
@@ -16,6 +16,8 @@
  *
  * Available configuration keys:
  * - index: The source property to check for.
+ * - message: (optional) A message to be logged in the {migrate_message_*} table
+ *   for this row. If is missed, nothing is logged in the message table.
  *
  * Example:
  *
@@ -26,10 +28,11 @@
  *      plugin: skip_row_if_not_set
  *      index: contact
  *      source: data
+ *      message: "Missed the 'data' key"
  * @endcode
  *
  * This will return $data['contact'] if it exists. Otherwise, the row will be
- * skipped.
+ * skipped and the message "Missed the 'data' key" will be logged.
  *
  * @see \Drupal\migrate\Plugin\MigrateProcessInterface
  *
@@ -45,7 +48,8 @@ class SkipRowIfNotSet extends ProcessPluginBase {
    */
   public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {
     if (!isset($value[$this->configuration['index']])) {
-      throw new MigrateSkipRowException();
+      $message = !empty($this->configuration['message']) ? $this->configuration['message'] : '';
+      throw new MigrateSkipRowException($message);
     }
     return $value[$this->configuration['index']];
   }
diff --git a/core/modules/migrate/tests/src/Unit/process/SkipOnEmptyTest.php b/core/modules/migrate/tests/src/Unit/process/SkipOnEmptyTest.php
index bf40dac..ce71c5a 100644
--- a/core/modules/migrate/tests/src/Unit/process/SkipOnEmptyTest.php
+++ b/core/modules/migrate/tests/src/Unit/process/SkipOnEmptyTest.php
@@ -1,6 +1,7 @@
 <?php
 
 namespace Drupal\Tests\migrate\Unit\process;
+
 use Drupal\migrate\Plugin\migrate\process\SkipOnEmpty;
 
 /**
@@ -13,12 +14,12 @@ class SkipOnEmptyTest extends MigrateProcessTestCase {
 
   /**
    * @covers ::process
-   * @expectedException \Drupal\migrate\MigrateSkipProcessException
    */
   public function testProcessSkipsOnEmpty() {
     $configuration['method'] = 'process';
     (new SkipOnEmpty($configuration, 'skip_on_empty', []))
       ->transform('', $this->migrateExecutable, $this->row, 'destinationproperty');
+    $this->setExpectedException(\Drupal\migrate\MigrateSkipProcessException);
   }
 
   /**
@@ -33,12 +34,12 @@ public function testProcessBypassesOnNonEmpty() {
 
   /**
    * @covers ::row
-   * @expectedException \Drupal\migrate\MigrateSkipRowException
    */
   public function testRowSkipsOnEmpty() {
     $configuration['method'] = 'row';
     (new SkipOnEmpty($configuration, 'skip_on_empty', []))
       ->transform('', $this->migrateExecutable, $this->row, 'destinationproperty');
+    $this->setExpectedException(\Drupal\migrate\MigrateSkipRowException);
   }
 
   /**
@@ -51,4 +52,35 @@ public function testRowBypassesOnNonEmpty() {
     $this->assertSame($value, ' ');
   }
 
+  /**
+   * Tests that a skip row exception without a message is raised.
+   *
+   * @covers ::row
+   * @expectedException \Drupal\migrate\MigrateSkipRowException
+   * @expectedExceptionMessage
+   */
+  public function testRowSkipWithoutMessage() {
+    $configuration = [
+      'method' => 'row',
+    ];
+    $process = new SkipOnEmpty($configuration, 'skip_on_empty', []);
+    $process->transform('', $this->migrateExecutable, $this->row, 'destinationproperty');
+  }
+
+  /**
+   * Tests that a skip row exception with a message is raised.
+   *
+   * @covers ::row
+   * @expectedException \Drupal\migrate\MigrateSkipRowException
+   * @expectedExceptionMessage The value is empty
+   */
+  public function testRowSkipWithMessage() {
+    $configuration = [
+      'method' => 'row',
+      'message' => 'The value is empty',
+    ];
+    $process = new SkipOnEmpty($configuration, 'skip_on_empty', []);
+    $process->transform('', $this->migrateExecutable, $this->row, 'destinationproperty');
+  }
+
 }
diff --git a/core/modules/migrate/tests/src/Unit/process/SkipRowIfNotSetTest.php b/core/modules/migrate/tests/src/Unit/process/SkipRowIfNotSetTest.php
new file mode 100644
index 0000000..abec296
--- /dev/null
+++ b/core/modules/migrate/tests/src/Unit/process/SkipRowIfNotSetTest.php
@@ -0,0 +1,46 @@
+<?php
+
+namespace Drupal\Tests\migrate\Unit\process;
+
+use Drupal\migrate\Plugin\migrate\process\SkipRowIfNotSet;
+
+/**
+ * Tests the skip row if not set process plugin.
+ *
+ * @group migrate
+ * @coversDefaultClass \Drupal\migrate\Plugin\migrate\process\SkipRowIfNotSet
+ */
+class SkipRowIfNotSetTest extends MigrateProcessTestCase {
+
+  /**
+   * Tests that a skip row exception without a message is raised.
+   *
+   * @covers ::transform
+   * @expectedExceptionMessage
+   */
+  public function testRowSkipWithoutMessage() {
+    $configuration = [
+      'index' => 'some_key',
+    ];
+    $process = new SkipRowIfNotSet($configuration, 'skip_row_if_not_set', []);
+    $process->transform('', $this->migrateExecutable, $this->row, 'destinationproperty');
+    $this->setExpectedException(\Drupal\migrate\MigrateSkipRowException);
+  }
+
+  /**
+   * Tests that a skip row exception with a message is raised.
+   *
+   * @covers ::transform
+   * @expectedExceptionMessage The 'some_key' key is not set
+   */
+  public function testRowSkipWithMessage() {
+    $configuration = [
+      'index' => 'some_key',
+      'message' => "The 'some_key' key is not set",
+    ];
+    $process = new SkipRowIfNotSet($configuration, 'skip_row_if_not_set', []);
+    $process->transform('', $this->migrateExecutable, $this->row, 'destinationproperty');
+    $this->setExpectedException(\Drupal\migrate\MigrateSkipRowException);
+  }
+
+}

diff --git a/core/modules/migrate/src/Plugin/migrate/process/SkipOnEmpty.php b/core/modules/migrate/src/Plugin/migrate/process/SkipOnEmpty.php
index 45626be..2768dbb 100644
--- a/core/modules/migrate/src/Plugin/migrate/process/SkipOnEmpty.php
+++ b/core/modules/migrate/src/Plugin/migrate/process/SkipOnEmpty.php
@@ -21,6 +21,9 @@
  *   - row: Skips the entire row when an empty value is encountered.
  *   - process: Prevents further processing of the input property when the value
  *     is empty.
+ * - message: (optional) A message to be logged in the {migrate_message_*} table
+ *   for this row. Messages are only logged for the 'row' skip level. If not
+ *   set, nothing is logged in the message table.
  *
  * Examples:
  *
@@ -30,9 +33,11 @@
  *     plugin: skip_on_empty
  *     method: row
  *     source: field_name
+ *     message: 'Field field_name is missed'
  * @endcode
  *
  * If field_name is empty, skips the entire row.
  *
  * @code
  * process:
@@ -79,7 +84,8 @@ class SkipOnEmpty extends ProcessPluginBase {
    */
   public function row($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {
     if (!$value) {
-      throw new MigrateSkipRowException();
+      $message = !empty($this->configuration['message']) ? $this->configuration['message'] : '';
+      throw new MigrateSkipRowException($message);
     }
     return $value;
   }
@@ -30,9 +33,11 @@
  * @endcode
  *
- * If field_name is empty, skips the entire row.
+ * If field_name is empty, skips the entire row and logs 'Field field_name is
+ * missed' in the message table.
  *
  * @code